@@ -37,9 +37,6 @@
 
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-#endif
 #ifdef Q_OS_ANDROID
     QGuiApplication app {argc, argv};
 #else
